package il.ac.tau.cs.sw1.simplesearch;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.List;

/**
 * <code>SimpleSearchEngine</code> builds an index of words given a list of
 * predefined URLs. It then will run word searches and URL similarity searches
 * based on user's input.
 */
public class SimpleSearchEngine {

	/**
	 * a list of urls we wish to index. feel free to add/remove urls from this
	 * list.
	 */
	static private String[] strURLs = {
			"http://en.wikipedia.org/wiki/Java_(programming_language)",
			"http://en.wikipedia.org/wiki/Java",
			"http://docs.oracle.com/javase/7/docs/technotes/guides/collections/reference.html",
			// Pride and Prejudice
			"http://www.gutenberg.org/files/1342/1342-h/1342-h.htm",
			// Great Expectations
			"http://www.gutenberg.org/files/1400/1400-h/1400-h.htm",
			// The Adventures of Huckleberry Finn
			"http://www.gutenberg.org/files/76/76-h/76-h.htm",
			// The Mysterious Affair at Styles
			"http://www.gutenberg.org/files/863/863-h/863-h.htm" };

	private WordIndex indexer; // reference to a WordIndex instance

	/**
	 * Create a new SimpleSearchEngine
	 * 
	 * @param index
	 *            - An instance implementing the {@link WordIndex} interface.
	 */
	public SimpleSearchEngine(WordIndex index) {
		this.indexer = index;
	}

	/**
	 * Populate the index and run searches
	 */
	public void run() {
		indexURLs(indexer);
		doSearches(indexer);
	}

	private static void indexURLs(WordIndex indexer) {
		for (String strURL : strURLs) {
			System.out.println("Indexing \"" + strURL + "\" ...");
			indexer.index(HTMLTokenizer.getTokens(strURL), strURL);
		}
	}

	private static void doSearches(WordIndex indexer) {

		try {
			BufferedReader in = new BufferedReader(
					new InputStreamReader(System.in));
			String str = null;
			do {
				System.out.print("> ");
				str = in.readLine().trim();
				if (str.equals("(exit)")) {
					break;
				}

				if (!str.startsWith("~")) {
					System.out
							.println("Searching for pages containing \""
									+ str + "\"...");
					// looking for pages containing the given word
					List<String> results = indexer.search(str);
					if (results == null || results.size() == 0) {
						System.out
								.println("\tUnable to find relevant pages.");
					} else {
						for (int i = 0; i < results.size(); ++i) {
							System.out.println(i + 1 + ".\t"
									+ results.get(i));
						}
					}
				} else {
					String url = str.substring(1);
					System.out
							.println("Searching for a page similar to URL \""
									+ url + "\"...");
					// looking for a similar page
					String result = indexer.findSimilarPage(url);
					if (result == null) {
						System.out
								.println("\tUnable to find a similar page.");
					} else {
						System.out.println("\t" + result);
					}
				}

			} while (true);

		} catch (IOException e) {
		}

		System.out.println("Thank you for using SimpleSearch");
	}

}
