package il.ac.tau.cs.sw1.simplesearch;

import java.util.Collection;
import java.util.List;

/**
 * A word index allows for a quick search over a large collection of web pages.
 */
public interface WordIndex {

	/**
	 * Add the words originating in the specifies URL.
	 * 
	 * @param words
	 *            - collection of words to add to the index
	 * @param strURL
	 *            - the location of the page containing the words
	 */
	void index(Collection<String> words, String strURL);

	/**
	 * Search for pages containing a given word in the index
	 * 
	 * @param word
	 *            - the word to search
	 * @return A list of pages containing the word. The pages are ordered
	 *         according to the relative importance of the word within them.
	 */
	List<String> search(String word);

	/**
	 * Search for pages that are similar to a given URL in the index
	 * 
	 * @param strURL
	 *            - a URL, possibly not in the index
	 * @return The page in the index that is the most similar to the input
	 *         strURL.
	 */
	String findSimilarPage(String strURL);
}